==> apache-answer-1.6.0-src.tar.gz: apache-answer-1.6.0-src/pkg/checker/reserved_username.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package checker

import (
	"encoding/json"
	"os"
	"path/filepath"
	"sync"

	"github.com/apache/answer/configs"
	"github.com/apache/answer/internal/cli"
	"github.com/apache/answer/pkg/dir"
)

var (
	reservedUsernameMapping = make(map[string]bool)
	reservedUsernameInit    sync.Once
)

func initReservedUsername() {
	reservedUsernamesJsonFilePath := filepath.Join(cli.ConfigFileDir, cli.DefaultReservedUsernamesConfigFileName)
	if dir.CheckFileExist(reservedUsernamesJsonFilePath) {
		// if reserved username file exists, read it and replace configuration
		reservedUsernamesJsonFile, err := os.ReadFile(reservedUsernamesJsonFilePath)
		if err == nil {
			configs.ReservedUsernames = reservedUsernamesJsonFile
		}
	}
	var usernames []string
	_ = json.Unmarshal(configs.ReservedUsernames, &usernames)
	for _, username := range usernames {
		reservedUsernameMapping[username] = true
	}
}

// IsReservedUsername checks whether the username is reserved
func IsReservedUsername(username string) bool {
	reservedUsernameInit.Do(initReservedUsername)
	return reservedUsernameMapping[username]
}

==> apache-answer-1.7.1-src.tar.gz: apache-answer-1.7.1-src/pkg/checker/reserved_username.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package checker

import (
	"encoding/json"
	"os"
	"path/filepath"
	"sync"

	"github.com/apache/answer/configs"
	"github.com/apache/answer/internal/base/path"
	"github.com/apache/answer/pkg/dir"
)

var (
	reservedUsernameMapping = make(map[string]bool)
	reservedUsernameInit    sync.Once
)

func initReservedUsername() {
	reservedUsernamesJsonFilePath := filepath.Join(path.ConfigFileDir, path.DefaultReservedUsernamesConfigFileName)
	if dir.CheckFileExist(reservedUsernamesJsonFilePath) {
		// if reserved username file exists, read it and replace configuration
		reservedUsernamesJsonFile, err := os.ReadFile(reservedUsernamesJsonFilePath)
		if err == nil {
			configs.ReservedUsernames = reservedUsernamesJsonFile
		}
	}
	var usernames []string
	_ = json.Unmarshal(configs.ReservedUsernames, &usernames)
	for _, username := range usernames {
		reservedUsernameMapping[username] = true
	}
}

// IsReservedUsername checks whether the username is reserved
func IsReservedUsername(username string) bool {
	reservedUsernameInit.Do(initReservedUsername)
	return reservedUsernameMapping[username]
}
